@@ -1,4 +1,4 @@
-import kubify.src.aws.s3_utils as module_0
+import src.core.utils.s3_utils as module_0
 
 
 def test_case_0():
